<?php

/*  Plugin Name: Zolton.org Social Plugin
    Plugin URI: http://www.zolton.org
    Description: Simple social networking integration for Wordpress.
    Version: 1.2.0	
    Author: Mark Zolton
    Author URI: http://www.zolton.org
    License: GPL2

    Copyright 2011  Mark Zolton  (email : mark@zolton.org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* Edit these values. */

// Facebook App ID 
define( 'ZO_FB_APPID', '10293847563875' ); 

// Twitter Username
define( 'ZO_TWITTER_USERNAME', 'yourusername'); 

// Default Facebook Image
define( 'ZO_FB_IMAGE', 'http://example.com/image.png'); 

// Add a "Send" button in addition to the Facebook Like button. 1=yes, 0=no
define( 'ZO_FB_LIKE_SEND', '1'); 

// Hides the Wordpress comment form. 1=yes, 0=no
define( 'ZO_HIDE_WPCOMMENTS', '0' );

/* You don't need to edit anything below this line unless you want to customize
 * something.
 */

/** Facebook FBML Namespace */
function zo_facebook_namespace($content) {
	return $content . ' xmlns:fb="http://www.facebook.com/2008/fbml"';
}

add_filter('language_attributes', 'zo_facebook_namespace');

/** Facebook Open Graph Tags */
function zo_facebook_og_tags() {
	
	$app_id = ZO_FB_APPID;
	
	// Always add the OG tag for app_id.
	echo <<<END
<!-- ZO: Facebook Open Graph Tags -->
<meta property="fb:app_id" content="{$app_id}" />
END;

	// If this is a single post, add additional OG tags (generally used by the Like Button).
	if( is_singular() ) {	
			 
		$title = esc_attr( single_post_title( '', FALSE ) );
		$site_name = esc_attr( get_bloginfo( 'name' ) );
		$url = esc_url( get_permalink() );
		$image = ZO_FB_IMAGE;
		
		// Get the featured image, if one exists.
        if ( has_post_thumbnail( get_the_ID() ) ) {
            $image = wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) );
        }
        
        $image = esc_url( $image );
		
		echo <<<END
<meta property="og:title" content="{$title}" />
<meta property="og:site_name" content="{$site_name}" />
<meta property="og:url" content="{$url}" />
<meta property="og:type" content="website" />
<meta property="og:image" content="{$image}" />
END;
		
	}
	
	echo '<!-- ZO: End Facebook Open Graph Tags -->';
}

add_action( 'wp_head', 'zo_facebook_og_tags' );

/** Facebook JavaScript SDK */
function zo_facebook_js_sdk($c) {
	
	$app_id = ZO_FB_APPID;

    	echo <<<END
    <div id="fb-root"></div>
    <script type="text/javascript">
      window.fbAsyncInit = function() {
        FB.init({appId: '{$app_id}', status: true, cookie: true,
                 xfbml: true});
      };
      (function() {
        var e = document.createElement('script');
        e.type = 'text/javascript';
        e.src = document.location.protocol +
          '//connect.facebook.net/en_US/all.js';
        e.async = true;
        document.getElementById('fb-root').appendChild(e);
      }());
    </script>
END;

}

add_filter( 'wp_footer', 'zo_facebook_js_sdk' );

/** Facebook Comments */
function zo_facebook_comments () {
	
	if( is_singular() && comments_open() ) {
		
		$url = esc_url( get_permalink() );
		$width = '610';
		
		/* Sets the width of Facebook Comments based on the template.
		 * At Zolton.org, we use a template called "onecolumn-page" 
		 * that is wider than a multi-column page. If "onecolumn-page" 
		 * is not in use, just the multi-column width.
		 */
		if( strpos( get_page_template(), 'onecolumn' ) ) {
			$width = '640';
		} 
		
		echo <<<END
<!-- ZO: Facebook Comments -->
<div id="facebook-comments">
<h3 id="facebook-reply-title">Add a Facebook Comment</h3>
<fb:comments href="{$url}" num_posts="3" width="{$width}" publish></fb:comments>
</div>
<!-- ZO: End Facebook Comments -->
END;

	}
}

add_filter( 'comments_template',  'zo_facebook_comments');

/** Social Buttons */
function zo_social_buttons( $content ) {

	$new_content = '';
	
	// If this is a single post, add additional OG tags (generally used by the Like Button).
	if( is_singular() && comments_open() ) {
		
		$url = esc_url( get_permalink() );
		$twitter_username = ZO_TWITTER_USERNAME;
		$send = ZO_FB_LIKE_SEND;
		
		$new_content = <<<END
<!-- ZO: Social Buttons --> 
<div class="social-buttons"> 
	<a href="http://twitter.com/share" class="twitter-share-button" data-count="horizontal" data-via="{$twitter_username}">Tweet</a>
	<script type="text/javascript" src="http://platform.twitter.com/widgets.js"></script>
	<fb:like href="{$url}" layout="button_count" show_faces="false" width="400" font="" send="{$send}"></fb:like>
</div>
<!-- ZO: End Social Buttons -->
END;

	}
	
	return $content . $new_content;
	
}

add_filter( 'the_content', 'zo_social_buttons' );

/** Hide the Wordpress comment form? */
if(ZO_HIDE_WPCOMMENTS == '1')
{
	function zo_hide_wpcomments()
	{
		$path = plugins_url('css/zosp-hide-wpcomments.css', __FILE__);
		
		wp_register_style('zosp_hide_wpcomments', $path);
        wp_enqueue_style('zosp_hide_wpcomments');
	}
	
	add_action('init', 'zo_hide_wpcomments');
}

?>
